@@ -30,6 +30,7 @@
 
 static void leon_reboot(char *bcommand);
 static void leon_halt(void);
+static void leon_v0_feval(int len, char *str);
 static int leon_nbgetchar(void);
 static int leon_nbputchar(int c);
 
@@ -110,7 +111,7 @@ struct linux_romvec romvector = {
 	NULL,
 	leon_halt,
 	NULL_PPTR,
-	{NULL},
+	{leon_v0_feval},
 	&bootargs_p,
 	/*... */
 };
@@ -316,6 +317,13 @@ static void leon_halt(void)
 		;
 }
 
+static void leon_v0_feval(int len, char *str)
+{
+	if (_strcmp("reset", str) == 0) {
+		leon_reboot(NULL);
+	}
+}
+
 /* get single char, don't care for blocking */
 static int leon_nbgetchar(void)
 {
