@@ -335,7 +335,7 @@ int conf_read_level(const char *name, struct conf_level *l)
 	struct expr *e;
 	int i, flags;
 
-	sym_set_change_count(0);
+	/*sym_set_change_count(0);*/
 
 	if (conf_read_simple_level(name, S_DEF_USER, l))
 		return 1;
@@ -358,10 +358,15 @@ int conf_read_level(const char *name, struct conf_level *l)
 					goto sym_ok;
 				break;
 			}
-		} else if (!sym_has_value(sym) && !(sym->flags & SYMBOL_WRITE))
+		} else if (!sym_has_value(sym) && !(sym->flags & SYMBOL_WRITE)) {
 			/* no previous value and not saved */
 			goto sym_ok;
+		} else if (sym_get_type(sym) == S_EXECUTE)
+			goto sym_ok;
+		
 		conf_unsaved++;
+		printf("%s unsaved\n", sym->name);
+		
 		/* maybe print value in verbose mode... */
 	sym_ok:
 		if (!sym_is_choice(sym))
@@ -409,7 +414,9 @@ int conf_read_level(const char *name, struct conf_level *l)
 }
 
 int conf_read(const char *name) {
-	int r = conf_read_level(name, 0);
+	int r;
+	sym_set_change_count(0);
+ 	r = conf_read_level(name, 0);
 	if (!r && !name) {
 		struct conf_level *l = conf_levels;
 		while (l) {
