@@ -21,8 +21,10 @@ if [ -z "$FTP_BASE" -o -z "$LOCAL_PATH" -o -z "$BASENAME" ]; then
 fi
 
 rm -f $LOCAL_PATH/.LATEST.$BASENAME
+mkdir -p $LOCAL_PATH
+
 if ! $GET $FTP_BASE/CURRENT.$BASENAME $LOCAL_PATH/.LATEST.$BASENAME ; then
-	echo "Failed to access FTP server 1"
+	echo "Failed to download $FTP_BASE/CURRENT.$BASENAME to $LOCAL_PATH/.LATEST.$BASENAME"
 	exit 2
 fi
 
@@ -45,7 +47,19 @@ req_rev=`echo $req_ver | cut -d'.' -f3`
 
 echo "Current LINUXBUILD version $lb_major.$lb_minor.$lb_rev, package requires $req_major.$req_minor.$req_rev"
 
-if [ $req_major -ne $lb_major   -o   $req_minor -ne $lb_minor   -o   $req_rev -gt $lb_rev ]; then
+verfail=0
+if [ $lb_major -lt $req_major ] ; then
+	verfail=1
+elif [ $lb_major -eq $req_major ] ; then
+	if [ $lb_minor -lt $req_minor ] ; then
+		verfail=1
+	elif [ $lb_minor -eq $req_minor ] ; then
+		if [ $lb_rev -lt $req_rev ] ; then
+			verfail=1
+		fi
+	fi
+fi
+if [ $verfail -eq 1 ] ; then
 	rm -f $LOCAL_PATH/.LATEST.$BASENAME
 	echo
 	echo  "!!! latest versions on server requires a newer LINUXBUILD version"
@@ -66,7 +80,7 @@ fi
 
 if ! $GET $FTP_BASE/$filename $LOCAL_PATH/.$filename ; then
 	rm -f $LOCAL_PATH/.$filename $LOCAL_PATH/.LATEST.$BASENAME
-	echo "Failed to access FTP server 2"
+	echo "Failed to download $FTP_BASE/$filename to $LOCAL_PATH/.$filename"
 	exit 2
 fi
 
