@@ -5,6 +5,7 @@
 #include <startup.h>
 #include <prom.h>
 #include <ambapp.h>
+#include <ambapp_names.h>
 #include <gptimer.h>
 #include <irqmp.h>
 #include <apbuart.h>
@@ -168,31 +169,26 @@ int ambapp_prop_int(struct prop_std *buf, const char *prop_str, int value);
 int ambapp_prop_str(struct prop_std *buf, const char *prop_str, const char *val_str);
 int ambapp_prop_uintarray(struct prop_std *buf, const char *prop_str,
 			  unsigned int *array, int len);
+int ambapp_prop_str_array(struct prop_std *buf, const char *prop_str,
+			  const char *val_array[]);
 int ambapp_prop_empty(struct prop_std *buf, const char *prop_str);
 
+const char *canoc_compatibles[] = {
+	"gaisler,can_oc",
+	"aeroflexgaisler,can_oc",
+	"nxp,sja1000",
+	NULL
+};
+
 int canoc_ahb_fixup_prop(ambapp_core *core, struct prop_std *buf, int index)
 {
 	int val;
-	char *str;
-	const char *strval;
-	const char *compatibles[] =  {"aeroflexgaisler,can_oc", "nxp,sja1000", NULL};
-	int i, len;
 	static char *prop_str_nxpfreq = NULL;
 
 	switch (index) {
 	case 0:
-		ambapp_prop_init(buf, prop_str_compatible);
-		str = (char *)&buf->v.data[0];
-		buf->length = 0;
-		for(i = 0; compatibles[i]; i++) {
-			strval = compatibles[i];
-			len = 1 + _strnlen(strval, 64);
-			_strcpy(str, (char *)strval);
-			str += len;
-			buf->length += len;
-		}
-		return sizeof(struct prop_data) + buf->length;
-
+		return ambapp_prop_str_array(buf, prop_str_compatible,
+					     canoc_compatibles);
 	case 1:
 		PROM_STRDUP_ONCE(prop_str_nxpfreq, "nxp,external-clock-frequency");
 		val = ambapp_dev_freq((ambapp_dev *)core->ahbslv);
@@ -203,6 +199,11 @@ int canoc_ahb_fixup_prop(ambapp_core *core, struct prop_std *buf, int index)
 	}
 }
 
+const char *i2c_compatibles[] = {
+	"gaisler,i2cmst",
+	"aeroflexgaisler,i2cmst",
+	NULL
+};
 
 int i2c_fixup_prop(ambapp_core *core, struct prop_std *buf, int index)
 {
@@ -211,8 +212,8 @@ int i2c_fixup_prop(ambapp_core *core, struct prop_std *buf, int index)
 
 	switch (index) {
 	case 0:
-		return ambapp_prop_str(buf, prop_str_compatible,
-				       "aeroflexgaisler,i2cmst");
+		return ambapp_prop_str_array(buf, prop_str_compatible,
+					     i2c_compatibles);
 	case 1:
 		/* Set "clock-frequency" */
 		val = ambapp_dev_freq((ambapp_dev *)core->apbslv);
@@ -226,14 +227,20 @@ int i2c_fixup_prop(ambapp_core *core, struct prop_std *buf, int index)
 	}
 }
 
+const char *spi_compatibles[] = {
+	"gaisler,spictrl",
+	"aeroflexgaisler,spictrl",
+	NULL
+};
+
 int spi_fixup_prop(ambapp_core *core, struct prop_std *buf, int index)
 {
 	int val;
 
 	switch (index) {
 	case 0:
-		return ambapp_prop_str(buf, prop_str_compatible,
-				       "aeroflexgaisler,spictrl");
+		return ambapp_prop_str_array(buf, prop_str_compatible,
+					     spi_compatibles);
 	case 1:
 		/* Set "clock-frequency" */
 		val = ambapp_dev_freq((ambapp_dev *)core->apbslv);
@@ -311,7 +318,7 @@ int grgpio_fixup_prop(ambapp_core *core, struct prop_std *buf, int index)
 		return ambapp_prop_uintarray(buf, prop_str_irqmap,
 					     gp->irqmap, gp->nbits);
 	case 2:
-		PROM_STRDUP_ONCE(prop_str_gpiocontroller, "gpiocontroller");
+		PROM_STRDUP_ONCE(prop_str_gpiocontroller, "gpio-controller");
 		return ambapp_prop_empty(buf, prop_str_gpiocontroller);
 	case 3:
 		PROM_STRDUP_ONCE(prop_str_ngpiocells, "#gpio-cells");
@@ -386,15 +393,16 @@ static void grgpio_probe(int idx, struct grgpio_regs *regs, struct grgpio_fixup_
 		if(read != readback) {
 			gp->irqmode = GRGPIO_IRQMODE_MAP;
 			BYPASS_STORE_PA(&regs->imap[0], read);
+		} else {
+			/*
+			 * irqgen == 0 and irqgen == 1 cannot be distinguished
+			 * for version 1 of the core without going outside the
+			 * grgpio core. Therefore, this has to be configured
+			 * from the outside instead
+			 */
+			DBG_PRINTF1("grgpio%d: interrupts disabled - cannot distinguish irqgen 0 from 1\n",
+				    idx);
 		}
-
-		/*
-		 * irqgen == 0 and irqgen == 1 cannot be distinguished for
-		 * version 1 of the core without going outside the grgpio
-		 * core. Therefore, this has to be configured from the outside
-		 * instead
-		 */
-		DBG_PRINTF1("grgpio%d: interrupts disabled - cannot distinguish irqgen 0 from 1\n", idx);
 	}
 
 	/* Restore original imask */
@@ -1509,6 +1517,11 @@ ambapp_core *ambapp_core_create(
 	device = dev->device;
 	ver = dev->ver;
 
+#ifdef CONFIG_DEBUG
+	core->vendor = vendor;
+	core->device = device;
+#endif
+
 	/* Find a AHB Slave for Device */
 	if (options & 0x2) {
 		for (i = 0, ahbbus = ainfo->ahbs;
@@ -1846,6 +1859,28 @@ int ambapp_prop_uintarray(struct prop_std *buf, const char *prop_str,
 	return sizeof(struct prop_data) + dp->length;
 }
 
+int ambapp_prop_str_array(struct prop_std *buf, const char *prop_str,
+			  const char *val_array[])
+{
+	char *str;
+	int len;
+	int i;
+
+	ambapp_prop_init(buf, prop_str);
+	str = (char *)&buf->v.data[0];
+	buf->length = 0;
+	for(i = 0; val_array[i]; i++) {
+		const char *strval = val_array[i];
+
+		len = 1 + _strnlen(strval, 64);
+		_strcpy(str, (char *)strval);
+		str += len;
+		buf->length += len;
+	}
+	return sizeof(struct prop_data) + buf->length;
+
+}
+
 int ambapp_prop_empty(struct prop_std *buf, const char *prop_str)
 {
 	return ambapp_prop_uintarray(buf, prop_str, NULL, 0);
@@ -1861,8 +1896,8 @@ int ambapp_prop_name(ambapp_core *core, struct prop_std *buf)
 	str = (char *)&buf->v.data[0];
 
 	/* Find Device and Vendor String from AMBA PnP Data Base */
-	device = ambapp_device_id2str(dev->vendor, dev->device);
-	vendor = ambapp_vendor_id2str(dev->vendor);
+	device = ambapp_device_id2str(ambapp_ids, dev->vendor, dev->device);
+	vendor = ambapp_vendor_id2str(ambapp_ids, dev->vendor);
 	if (device && vendor) {
 		_strcpy(str, (char *)vendor);
 		buf->length = _strnlen(vendor, 32);
@@ -2056,7 +2091,8 @@ int ambapp_prop_description(ambapp_core *core, struct prop_std *buf)
 {
 	/* Find Device description from AMBA PnP Data Base */
 	ambapp_dev *dev = ambapp_get_first_dev(core);
-	const char *desc = ambapp_device_id2desc(dev->vendor, dev->device);
+	const char *desc = ambapp_device_id2desc(ambapp_ids,
+						 dev->vendor, dev->device);
 
 	return ambapp_prop_str(buf, prop_str_description, desc);
 }
